@@ -627,10 +627,12 @@ matrix<T> ::pivot (size_t row)
 
   amax = -1;
   for (size_t i=row; i < _m->Row; i++)
-    if ( (temp = abs( _m->Val[i][row])) > amax && temp != 0.0)
+    if ( (temp = abs( _m->Val[i][row])) > amax)
      {
-       amax = temp;
-       k = i;
+       if(temp!=0.0){
+         amax = temp;
+         k = i;
+       }
      }
   if (_m->Val[k][row] == T(0))
      return -1;
